==> dokuwiki-2013.05.10.tgz: dokuwiki/inc/lang/lb/lang.php <==
<?php
/**
 * lb language file
 *
 * @author joel@schintgen.net
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Dës Säit änneren';
$lang['btn_source']            = 'Säitequell weisen';
$lang['btn_show']              = 'Säit weisen';
$lang['btn_create']            = 'Dës Säit uleeën';
$lang['btn_search']            = 'Sichen';
$lang['btn_save']              = 'Späicheren';
$lang['btn_preview']           = 'Kucken ouni ofzespäicheren';
$lang['btn_top']               = 'Zréck no uewen';
$lang['btn_newer']             = '<< méi rezent';
$lang['btn_older']             = 'manner rezent >>';
$lang['btn_revs']              = 'Al Versiounen';
$lang['btn_recent']            = 'Kierzlech Ännerungen';
$lang['btn_upload']            = 'Eroplueden';
$lang['btn_cancel']            = 'Ofbriechen';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Änneren';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Logout';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Update';
$lang['btn_delete']            = 'Läschen';
$lang['btn_back']              = 'Zeréck';
$lang['btn_backlink']          = 'Linker zeréck';
$lang['btn_backtomedia']       = 'Zeréck bei d\'Auswiel vun de Mediadateien';
$lang['btn_profile']           = 'Profil aktualiséieren';
$lang['btn_reset']             = 'Zerécksetzen';
$lang['btn_draft']             = 'Entworf änneren';
$lang['btn_recover']           = 'Entworf zeréckhuelen';
$lang['btn_draftdel']          = 'Entworf läschen';
$lang['btn_register']          = 'Registréieren';
$lang['loggedinas']            = 'Ageloggt als';
$lang['user']                  = 'Benotzernumm';
$lang['pass']                  = 'Passwuert';
$lang['newpass']               = 'Nei Passwuert';
$lang['oldpass']               = 'Aktuell Passwuert confirméieren';
$lang['passchk']               = 'nach eng Kéier';
$lang['remember']              = 'Verhal mech';
$lang['fullname']              = 'Richtegen Numm';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Benotzerprofil';
$lang['badlogin']              = 'Entschëllegt, de Benotzernumm oder d\'Passwuert war falsch';
$lang['minoredit']             = 'Kleng Ännerungen';
$lang['draftdate']             = 'Entworf automatesch gespäichert den';
$lang['nosecedit']             = 'D\'Säit gouf an Zwëschenzäit g\'ännert, Sektiounsinfo veralt. Ganz Säit gouf aplaz gelueden.';
$lang['regmissing']            = 'Du muss all d\'Felder ausfëllen.';
$lang['reguexists']            = 'Et get schonn e Benotzer mat deem Numm.';
$lang['regsuccess']            = 'De Benotzer gouf erstallt an d\'Passwuert via Email geschéckt.';
$lang['regsuccess2']           = 'De Benotzer gouf erstallt.';
$lang['regmailfail']           = 'Et gesäit aus wéi wann e Feeler beim schécke vun der Passwuertmail virkomm wier. Kontaktéier den Admin w.e.g.!';
$lang['regbadmail']            = 'Déi Emailadress gesäit ongëlteg aus - wanns de mengs dat wier e Feeler, da kontaktéier den Admin w.e.g.';
$lang['regbadpass']            = 'Déi 2 Passwieder si net t\'selwecht. Probéier nach eng Kéier w.e.g.';
$lang['regpwmail']             = 'Däin DokuWiki Passwuert';
$lang['reghere']               = 'Hues du nach keen Account? Da maach der een';
$lang['profna']                = 'Dëse Wiki ënnestëtzt keng Ännerunge vum Profil';
$lang['profnochange']          = 'Keng Ännerungen. Näischt ze man.';
$lang['profnoempty']           = 'En eidele Numm oder Emailadress ass net erlaabt.';
$lang['profchanged']           = 'Benotzerprofil erfollegräicht aktualiséiert.';
$lang['pwdforget']             = 'Passwuert vergiess? Fro der e Neit';
$lang['resendna']              = 'Dëse Wiki ënnerstëtzt net d\'Neiverschécke vu Passwieder.';
$lang['resendpwdmissing']      = 'Du muss all Felder ausfëllen.';
$lang['resendpwdnouser']       = 'Kann dëse Benotzer net an der Datebank fannen.';
$lang['resendpwdbadauth']      = 'Den "Auth"-Code ass ongëlteg. Kuck no obs de dee ganze Konfirmationslink benotzt hues.';
$lang['resendpwdconfirm']      = 'De Konfirmatiounslink gouf iwwer Email geschéckt.';
$lang['resendpwdsuccess']      = 'Däi nei Passwuert gouf iwwer Email geschéckt.';
$lang['license']               = 'Wann näischt anescht do steet, ass den Inhalt vun dësem Wiki ënner folgender Lizenz:';
$lang['licenseok']             = 'Pass op: Wanns de dës Säit änners, bass de dermat averstan dass den Inhalt ënner folgender Lizenz lizenzéiert gëtt:';
$lang['txt_upload']            = 'Wiel eng Datei fir eropzelueden';
$lang['txt_filename']          = 'Eroplueden als (optional)';
$lang['txt_overwrt']           = 'Bestehend Datei iwwerschreiwen';
$lang['lockedby']              = 'Am Moment gespaart vun';
$lang['lockexpire']            = 'D\'Spär leeft of ëm';
$lang['js']['willexpire']            = 'Deng Spär fir d\'Säit ze änneren leeft an enger Minutt of.\nFir Konflikter ze verhënneren, dréck op Kucken ouni ofzespäicheren.';
$lang['js']['notsavedyet']     = 'Net gespäicher Ännerunge gi verluer.\nWierklech weiderfueren?';
$lang['rssfailed']             = 'Et ass e Feeler virkomm beim erofluede vun dësem Feed: ';
$lang['nothingfound']          = 'Näischt fond.';
$lang['mediaselect']           = 'Mediadateien';
$lang['fileupload']            = 'Mediadateien eroplueden';
$lang['uploadsucc']            = 'Upload erfollegräich';
$lang['uploadfail']            = 'Feeler beim Upload. Vläicht falsch Rechter?';
$lang['uploadwrong']           = 'Eroplueden net erlaabt. Dës Dateiendung ass verbueden!';
$lang['uploadexist']           = 'Datei gët et schonn. Näischt gemaach.';
$lang['uploadbadcontent']      = 'Den eropgeluedenen Inhalt stëmmt net mat der Dateiendung %s iwwereneen.';
$lang['uploadspam']            = 'D\'Eropluede gouf duerch d\'Schwaarz Spamlëscht blockéiert.';
$lang['uploadxss']             = 'D\'Eropluede gouf wéinst méiglechem béisaartegem Inhalt blockéiert.';
$lang['uploadsize']            = 'Déi eropgelueden Datei war ze grouss. (max. %s)';
$lang['deletesucc']            = 'D\'Datei "%s" gouf geläscht.';
$lang['deletefail']            = '"%s" konnt net geläscht ginn. Kontroléier d\'Rechter.';
$lang['mediainuse']            = 'D\'Datei "%s" gouf net geläscht - se ass nach am Gebrauch.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'Verfügbar Dateien am';
$lang['js']['keepopen']        = 'Fënster beim Auswielen oploossen';
$lang['js']['hidedetails']     = 'Deteiler verstoppen';
$lang['mediausage']            = 'Benotz folgend Syntax fir dës Datei ze referenzéieren:';
$lang['mediaview']             = 'Originaldatei weisen';
$lang['mediaroot']             = 'root';
$lang['mediaextchange']        = 'Dateiendung vun .%s op .%s g\'ännert!';
$lang['reference']             = 'Referenzen fir';
$lang['ref_inuse']             = 'D\'Datei ka net geläscht ginn wëll se nach ëmmer vu folgende Säite gebraucht gëtt:';
$lang['ref_hidden']            = 'Verschidde Referenze sinn op Säiten wous de keng Rechter hues fir se ze kucken';
$lang['hits']                  = 'Treffer';
$lang['quickhits']             = 'Säitenimm déi iwwereneestëmmen';
$lang['toc']                   = 'Inhaltsverzeechnes';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Deng Versioun';
$lang['diff']                  = 'Weis d\'Ënnerscheeder zuer aktueller Versioun';
$lang['diff2']                 = 'Weis d\'Ënnerscheeder zwescht den ausgewielte Versiounen';
$lang['line']                  = 'Linn';
$lang['breadcrumb']            = 'Spuer';
$lang['youarehere']            = 'Du bass hei';
$lang['lastmod']               = 'Fir d\'lescht g\'ännert';
$lang['by']                    = 'vun';
$lang['deleted']               = 'geläscht';
$lang['created']               = 'erstallt';
$lang['restored']              = 'al Versioun zeréckgeholl (%s)';
$lang['external_edit']         = 'extern Ännerung';
$lang['summary']               = 'Resumé vun den Ännerungen';
$lang['noflash']               = 'Den <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> get gebraucht fir dësen Inhalt unzeweisen.';
$lang['mail_newpage']          = 'Säit bäigesat:';
$lang['mail_changed']          = 'Säit geännert:';
$lang['mail_subscribe_list']   = 'g\'ännert Säiten am Namespace:';
$lang['mail_new_user']         = 'Neie Benotzer:';
$lang['mail_upload']           = 'Datei eropgelueden:';
$lang['qb_bold']               = 'Fetten Text';
$lang['qb_italic']             = 'Schiefen Text';
$lang['qb_underl']             = 'Ënnerstrachenen Text';
$lang['qb_code']               = 'Code Text';
$lang['qb_strike']             = 'Duerchgestrachenen Text';
$lang['qb_h1']                 = 'Iwwerschrëft vum 1. Niveau';
$lang['qb_h2']                 = 'Iwwerschrëft vum 2. Niveau';
$lang['qb_h3']                 = 'Iwwerschrëft vum 3. Niveau';
$lang['qb_h4']                 = 'Iwwerschrëft vum 4. Niveau';
$lang['qb_h5']                 = 'Iwwerschrëft vum 5. Niveau';
$lang['qb_h']                  = 'Iwwerschrëft';
$lang['qb_hs']                 = 'Iwwerschrëft auswielen';
$lang['qb_hplus']              = 'Méi grouss Iwwerschrëft';
$lang['qb_hminus']             = 'Méi kleng Iwwerschrëft';
$lang['qb_hequal']             = 'Iwwerschrëft vum selwechte Niveau';
$lang['qb_link']               = 'Interne Link';
$lang['qb_extlink']            = 'Externe Link';
$lang['qb_hr']                 = 'Horizontale Stréch';
$lang['qb_ol']                 = 'Nummeréiert Lëscht';
$lang['qb_ul']                 = 'Onnummeréiert Lëscht';
$lang['qb_media']              = 'Biller an aner Dateie bäisetzen';
$lang['qb_sig']                = 'Ënnerschrëft afügen';
$lang['qb_smileys']            = 'Smilien';
$lang['qb_chars']              = 'Spezialzeechen';
$lang['upperns']               = 'An de Namespace uewendriwwer sprangen';
$lang['admin_register']        = 'Neie Benotzer bäisetzen';
$lang['metaedit']              = 'Metadaten änneren';
$lang['metasaveerr']           = 'Feeler beim Schreiwe vun de Metadaten';
$lang['metasaveok']            = 'Metadate gespäichert';
$lang['img_backto']            = 'Zeréck op';
$lang['img_title']             = 'Titel';
$lang['img_caption']           = 'Beschreiwung';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Dateinumm';
$lang['img_fsize']             = 'Gréisst';
$lang['img_artist']            = 'Fotograf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Format';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Schlësselwieder';
$lang['authmodfailed']         = 'Falsch Konfiguratioun vun der Benotzerautentifikatioun. Informéier w.e.g. de Wiki Admin.';
$lang['authtempfail']          = 'D\'Benotzerautentifikatioun ass de Moment net verfügbar. Wann dës Situatioun unhält, dann informéier w.e.g. de Wiki Admin.';
$lang['i_chooselang']          = 'Wiel deng Sprooch';
$lang['i_installer']           = 'DokuWiki Installer';
$lang['i_wikiname']            = 'Numm vum Wiki';
$lang['i_enableacl']           = 'ACL uschalten (rekommandéiert)';
$lang['i_problems']            = 'Den Installer huet Problemer fond. Se stinn hei ënnendrënner. Du kanns net weiderfueren bis de se behuewen hues.';
$lang['i_modified']            = 'Aus Sécherheetsgrënn funktionnéiert dëse Script nëmme mat enger neier an onverännerter Dokuwiki Installatioun. Entweder muss de d\'Dateie frësch extrahéieren oder kuck d\'komplett <a href="http://dokuwiki.org/install">Dokuwiki Installatiounsinstruktiounen</a>';
$lang['i_funcna']              = 'PHP-Funktioun <code>%s</code> ass net verfügbar. Vläicht huet däi Provider se aus iergend engem Grond ausgeschalt.';
$lang['i_phpver']              = 'Deng PHP-Versioun <code>%s</code> ass méi kleng wéi déi gebrauchte Versioun <code>%s</code>. Du muss deng PHP-Installatioun aktualiséieren. ';
$lang['i_pol0']                = 'Oppene Wiki (liese, schreiwen an eroplueden fir jidfereen)';
$lang['i_pol1']                = 'Ëffentleche Wiki (liesen fir jidfereen, schreiwen an eroplueden fir registréiert Benotzer)';
$lang['i_pol2']                = 'Zouene Wiki (liesen, schreiwen, eroplueden nëmme fir registréiert Benotzer)';
$lang['i_retry']               = 'Nach eng Kéier probéieren';
$lang['recent_global']         = 'Du kucks am Moment d\'Ännerungen innerhalb vum <b>%s</b> Namespace. Du kanns och <a href="%s">d\'Kierzilech Ännerungen vum ganze Wiki kucken</a>.';
$lang['years']                 = 'virun %d Joer';
$lang['months']                = 'virun %d Méint';
$lang['weeks']                 = 'virun %d Wochen';
$lang['days']                  = 'virun %d Deeg';
$lang['hours']                 = 'virun %d Stonnen';
$lang['minutes']               = 'virun %d Minutten';
$lang['seconds']               = 'virun %d Sekonnen';

==> dokuwiki-2023.04.04p2.tgz: dokuwiki/inc/lang/lb/lang.php <==
<?php
/**
 * lb language file
 *
 * @author joel@schintgen.net
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Dës Säit änneren';
$lang['btn_source']            = 'Säitequell weisen';
$lang['btn_show']              = 'Säit weisen';
$lang['btn_create']            = 'Dës Säit uleeën';
$lang['btn_search']            = 'Sichen';
$lang['btn_save']              = 'Späicheren';
$lang['btn_preview']           = 'Kucken ouni ofzespäicheren';
$lang['btn_top']               = 'Zréck no uewen';
$lang['btn_newer']             = '<< méi rezent';
$lang['btn_older']             = 'manner rezent >>';
$lang['btn_revs']              = 'Al Versiounen';
$lang['btn_recent']            = 'Kierzlech Ännerungen';
$lang['btn_upload']            = 'Eroplueden';
$lang['btn_cancel']            = 'Ofbriechen';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Änneren';
$lang['btn_login']             = 'Login';
$lang['btn_logout']            = 'Logout';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Update';
$lang['btn_delete']            = 'Läschen';
$lang['btn_back']              = 'Zeréck';
$lang['btn_backlink']          = 'Linker zeréck';
$lang['btn_profile']           = 'Profil aktualiséieren';
$lang['btn_reset']             = 'Zerécksetzen';
$lang['btn_draft']             = 'Entworf änneren';
$lang['btn_recover']           = 'Entworf zeréckhuelen';
$lang['btn_draftdel']          = 'Entworf läschen';
$lang['btn_register']          = 'Registréieren';
$lang['loggedinas']            = 'Ageloggt als:';
$lang['user']                  = 'Benotzernumm';
$lang['pass']                  = 'Passwuert';
$lang['newpass']               = 'Nei Passwuert';
$lang['oldpass']               = 'Aktuell Passwuert confirméieren';
$lang['passchk']               = 'nach eng Kéier';
$lang['remember']              = 'Verhal mech';
$lang['fullname']              = 'Richtegen Numm';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Benotzerprofil';
$lang['badlogin']              = 'Entschëllegt, de Benotzernumm oder d\'Passwuert war falsch';
$lang['minoredit']             = 'Kleng Ännerungen';
$lang['draftdate']             = 'Entworf automatesch gespäichert den';
$lang['nosecedit']             = 'D\'Säit gouf an Zwëschenzäit g\'ännert, Sektiounsinfo veralt. Ganz Säit gouf aplaz gelueden.';
$lang['regmissing']            = 'Du muss all d\'Felder ausfëllen.';
$lang['reguexists']            = 'Et get schonn e Benotzer mat deem Numm.';
$lang['regsuccess']            = 'De Benotzer gouf erstallt an d\'Passwuert via Email geschéckt.';
$lang['regsuccess2']           = 'De Benotzer gouf erstallt.';
$lang['regmailfail']           = 'Et gesäit aus wéi wann e Feeler beim schécke vun der Passwuertmail virkomm wier. Kontaktéier den Admin w.e.g.!';
$lang['regbadmail']            = 'Déi Emailadress gesäit ongëlteg aus - wanns de mengs dat wier e Feeler, da kontaktéier den Admin w.e.g.';
$lang['regbadpass']            = 'Déi 2 Passwieder si net t\'selwecht. Probéier nach eng Kéier w.e.g.';
$lang['regpwmail']             = 'Däin DokuWiki Passwuert';
$lang['reghere']               = 'Hues du nach keen Account? Da maach der een';
$lang['profna']                = 'Dëse Wiki ënnestëtzt keng Ännerunge vum Profil';
$lang['profnochange']          = 'Keng Ännerungen. Näischt ze man.';
$lang['profnoempty']           = 'En eidele Numm oder Emailadress ass net erlaabt.';
$lang['profchanged']           = 'Benotzerprofil erfollegräicht aktualiséiert.';
$lang['pwdforget']             = 'Passwuert vergiess? Fro der e Neit';
$lang['resendna']              = 'Dëse Wiki ënnerstëtzt net d\'Neiverschécke vu Passwieder.';
$lang['resendpwdmissing']      = 'Du muss all Felder ausfëllen.';
$lang['resendpwdnouser']       = 'Kann dëse Benotzer net an der Datebank fannen.';
$lang['resendpwdbadauth']      = 'Den "Auth"-Code ass ongëlteg. Kuck no obs de dee ganze Konfirmationslink benotzt hues.';
$lang['resendpwdconfirm']      = 'De Konfirmatiounslink gouf iwwer Email geschéckt.';
$lang['resendpwdsuccess']      = 'Däi nei Passwuert gouf iwwer Email geschéckt.';
$lang['license']               = 'Wann näischt anescht do steet, ass den Inhalt vun dësem Wiki ënner folgender Lizenz:';
$lang['licenseok']             = 'Pass op: Wanns de dës Säit änners, bass de dermat averstan dass den Inhalt ënner folgender Lizenz lizenzéiert gëtt:';
$lang['txt_upload']            = 'Wiel eng Datei fir eropzelueden:';
$lang['txt_filename']          = 'Eroplueden als (optional):';
$lang['txt_overwrt']           = 'Bestehend Datei iwwerschreiwen';
$lang['lockedby']              = 'Am Moment gespaart vun:';
$lang['lockexpire']            = 'D\'Spär leeft of ëm:';
$lang['js']['willexpire']            = 'Deng Spär fir d\'Säit ze änneren leeft an enger Minutt of.\nFir Konflikter ze verhënneren, dréck op Kucken ouni ofzespäicheren.';
$lang['js']['notsavedyet']     = 'Net gespäicher Ännerunge gi verluer.\nWierklech weiderfueren?';
$lang['rssfailed']             = 'Et ass e Feeler virkomm beim erofluede vun dësem Feed: ';
$lang['nothingfound']          = 'Näischt fond.';
$lang['mediaselect']           = 'Mediadateien';
$lang['uploadsucc']            = 'Upload erfollegräich';
$lang['uploadfail']            = 'Feeler beim Upload. Vläicht falsch Rechter?';
$lang['uploadwrong']           = 'Eroplueden net erlaabt. Dës Dateiendung ass verbueden!';
$lang['uploadexist']           = 'Datei gët et schonn. Näischt gemaach.';
$lang['uploadbadcontent']      = 'Den eropgeluedenen Inhalt stëmmt net mat der Dateiendung %s iwwereneen.';
$lang['uploadspam']            = 'D\'Eropluede gouf duerch d\'Schwaarz Spamlëscht blockéiert.';
$lang['uploadxss']             = 'D\'Eropluede gouf wéinst méiglechem béisaartegem Inhalt blockéiert.';
$lang['uploadsize']            = 'Déi eropgelueden Datei war ze grouss. (max. %s)';
$lang['deletesucc']            = 'D\'Datei "%s" gouf geläscht.';
$lang['deletefail']            = '"%s" konnt net geläscht ginn. Kontroléier d\'Rechter.';
$lang['mediainuse']            = 'D\'Datei "%s" gouf net geläscht - se ass nach am Gebrauch.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'Verfügbar Dateien am';
$lang['js']['keepopen']        = 'Fënster beim Auswielen oploossen';
$lang['js']['hidedetails']     = 'Deteiler verstoppen';
$lang['mediausage']            = 'Benotz folgend Syntax fir dës Datei ze referenzéieren:';
$lang['mediaview']             = 'Originaldatei weisen';
$lang['mediaroot']             = 'root';
$lang['mediaextchange']        = 'Dateiendung vun .%s op .%s g\'ännert!';
$lang['reference']             = 'Referenzen fir';
$lang['ref_inuse']             = 'D\'Datei ka net geläscht ginn wëll se nach ëmmer vu folgende Säite gebraucht gëtt:';
$lang['ref_hidden']            = 'Verschidde Referenze sinn op Säiten wous de keng Rechter hues fir se ze kucken';
$lang['hits']                  = 'Treffer';
$lang['quickhits']             = 'Säitenimm déi iwwereneestëmmen';
$lang['toc']                   = 'Inhaltsverzeechnes';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Deng Versioun';
$lang['diff']                  = 'Weis d\'Ënnerscheeder zuer aktueller Versioun';
$lang['diff2']                 = 'Weis d\'Ënnerscheeder zwescht den ausgewielte Versiounen';
$lang['line']                  = 'Linn';
$lang['breadcrumb']            = 'Spuer:';
$lang['youarehere']            = 'Du bass hei:';
$lang['lastmod']               = 'Fir d\'lescht g\'ännert:';
$lang['by']                    = 'vun';
$lang['deleted']               = 'geläscht';
$lang['created']               = 'erstallt';
$lang['restored']              = 'al Versioun zeréckgeholl (%s)';
$lang['external_edit']         = 'extern Ännerung';
$lang['summary']               = 'Resumé vun den Ännerungen';
$lang['noflash']               = 'Den <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> get gebraucht fir dësen Inhalt unzeweisen.';
$lang['mail_newpage']          = 'Säit bäigesat:';
$lang['mail_changed']          = 'Säit geännert:';
$lang['mail_subscribe_list']   = 'g\'ännert Säiten am Namespace:';
$lang['mail_new_user']         = 'Neie Benotzer:';
$lang['mail_upload']           = 'Datei eropgelueden:';
$lang['qb_bold']               = 'Fetten Text';
$lang['qb_italic']             = 'Schiefen Text';
$lang['qb_underl']             = 'Ënnerstrachenen Text';
$lang['qb_code']               = 'Code Text';
$lang['qb_strike']             = 'Duerchgestrachenen Text';
$lang['qb_h1']                 = 'Iwwerschrëft vum 1. Niveau';
$lang['qb_h2']                 = 'Iwwerschrëft vum 2. Niveau';
$lang['qb_h3']                 = 'Iwwerschrëft vum 3. Niveau';
$lang['qb_h4']                 = 'Iwwerschrëft vum 4. Niveau';
$lang['qb_h5']                 = 'Iwwerschrëft vum 5. Niveau';
$lang['qb_h']                  = 'Iwwerschrëft';
$lang['qb_hs']                 = 'Iwwerschrëft auswielen';
$lang['qb_hplus']              = 'Méi grouss Iwwerschrëft';
$lang['qb_hminus']             = 'Méi kleng Iwwerschrëft';
$lang['qb_hequal']             = 'Iwwerschrëft vum selwechte Niveau';
$lang['qb_link']               = 'Interne Link';
$lang['qb_extlink']            = 'Externe Link';
$lang['qb_hr']                 = 'Horizontale Stréch';
$lang['qb_ol']                 = 'Nummeréiert Lëscht';
$lang['qb_ul']                 = 'Onnummeréiert Lëscht';
$lang['qb_media']              = 'Biller an aner Dateie bäisetzen';
$lang['qb_sig']                = 'Ënnerschrëft afügen';
$lang['qb_smileys']            = 'Smilien';
$lang['qb_chars']              = 'Spezialzeechen';
$lang['upperns']               = 'An de Namespace uewendriwwer sprangen';
$lang['metaedit']              = 'Metadaten änneren';
$lang['metasaveerr']           = 'Feeler beim Schreiwe vun de Metadaten';
$lang['metasaveok']            = 'Metadate gespäichert';
$lang['btn_img_backto']            = 'Zeréck op %s';
$lang['img_title']             = 'Titel:';
$lang['img_caption']           = 'Beschreiwung:';
$lang['img_date']              = 'Datum:';
$lang['img_fname']             = 'Dateinumm:';
$lang['img_fsize']             = 'Gréisst:';
$lang['img_artist']            = 'Fotograf:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Kamera:';
$lang['img_keywords']          = 'Schlësselwieder:';
$lang['authtempfail']          = 'D\'Benotzerautentifikatioun ass de Moment net verfügbar. Wann dës Situatioun unhält, dann informéier w.e.g. de Wiki Admin.';
$lang['i_chooselang']          = 'Wiel deng Sprooch';
$lang['i_installer']           = 'DokuWiki Installer';
$lang['i_wikiname']            = 'Numm vum Wiki';
$lang['i_enableacl']           = 'ACL uschalten (rekommandéiert)';
$lang['i_problems']            = 'Den Installer huet Problemer fond. Se stinn hei ënnendrënner. Du kanns net weiderfueren bis de se behuewen hues.';
$lang['i_modified']            = 'Aus Sécherheetsgrënn funktionnéiert dëse Script nëmme mat enger neier an onverännerter Dokuwiki Installatioun. Entweder muss de d\'Dateie frësch extrahéieren oder kuck d\'komplett <a href="https://www.dokuwiki.org/install">Dokuwiki Installatiounsinstruktiounen</a>';
$lang['i_funcna']              = 'PHP-Funktioun <code>%s</code> ass net verfügbar. Vläicht huet däi Provider se aus iergend engem Grond ausgeschalt.';
$lang['i_phpver']              = 'Deng PHP-Versioun <code>%s</code> ass méi kleng wéi déi gebrauchte Versioun <code>%s</code>. Du muss deng PHP-Installatioun aktualiséieren. ';
$lang['i_pol0']                = 'Oppene Wiki (liese, schreiwen an eroplueden fir jidfereen)';
$lang['i_pol1']                = 'Ëffentleche Wiki (liesen fir jidfereen, schreiwen an eroplueden fir registréiert Benotzer)';
$lang['i_pol2']                = 'Zouene Wiki (liesen, schreiwen, eroplueden nëmme fir registréiert Benotzer)';
$lang['i_retry']               = 'Nach eng Kéier probéieren';
$lang['recent_global']         = 'Du kucks am Moment d\'Ännerungen innerhalb vum <b>%s</b> Namespace. Du kanns och <a href="%s">d\'Kierzilech Ännerungen vum ganze Wiki kucken</a>.';
$lang['years']                 = 'virun %d Joer';
$lang['months']                = 'virun %d Méint';
$lang['weeks']                 = 'virun %d Wochen';
$lang['days']                  = 'virun %d Deeg';
$lang['hours']                 = 'virun %d Stonnen';
$lang['minutes']               = 'virun %d Minutten';
$lang['seconds']               = 'virun %d Sekonnen';
$lang['email_signature_text'] = 'Dës Mail gouf generéiert vun DokuWiki op
@DOKUWIKIURL@';
